@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2013-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from lino.ad import Plugin, _
 
@@ -11,7 +11,6 @@ class Plugin(Plugin):
 
     needs_plugins = ['lino_xl.lib.topics']
 
-
     def setup_main_menu(self, site, user_type, m):
         # mg = self.get_menu_group()
         mg = site.plugins.office
@@ -29,6 +28,12 @@ class Plugin(Plugin):
         m.add_action('blogs.AllEntries')
         # m.add_action('blogs.AllTaggings')
 
+    def get_quicklinks(self, user):
+        yield dict(instance=user,
+            action=self.site.models.blogs.MyEntries.insert_action,
+            label=_("New blog entry"))
+
+
     # def get_dashboard_items(self, user):
     #     from lino.core.dashboard import ActorItem
     #     yield ActorItem(
