@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2011-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from collections import OrderedDict
 
@@ -249,7 +249,7 @@ class MyTasks(Tasks):
     required_roles = dd.login_required(OfficeUser)
     column_names = 'priority start_date summary workflow_buttons project'
     params_panel_hidden = True
-    # default_end_date_offset = 30 # replaced by Plugin.mytasks_end_date
+    order_by = ["priority", "start_date", "start_time"]
 
     @classmethod
     def param_defaults(self, ar, **kw):
