@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2012-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from lino_xl.lib.ledger.utils import ZERO, ONE
 
@@ -127,13 +127,13 @@ class Line(Referrable, Duplicable, ExcerptTitle, ContactRelated):
             "Leave empty if you don't want any presences management."))
 
     options_cat = dd.ForeignKey(
-        'products.ProductCat',
+        'products.Category',
         verbose_name=_("Options category"),
         related_name="courses_lines_by_options_cat",
         blank=True, null=True)
 
     fees_cat = dd.ForeignKey(
-        'products.ProductCat',
+        'products.Category',
         verbose_name=_("Fees category"),
         related_name="courses_lines_by_fees_cat",
         blank=True, null=True)
