@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2008-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import datetime
 
@@ -13,6 +13,7 @@ from django.utils.text import format_lazy
 
 from lino.api import _
 from lino.mixins import BabelNamed, Sequenced, StructuredReferrable, Referrable
+from lino.utils.mldbc.mixins import BabelDesignated
 from lino.mixins.periods import DateRange
 from lino.mixins.duplicable import Duplicable
 from lino.mixins.registrable import Registrable
@@ -442,6 +443,16 @@ class PaymentTerm(BabelNamed, Referrable):
         return d
 
 
+class PaymentMethod(BabelDesignated):
+
+    class Meta:
+        app_label = 'ledger'
+        verbose_name = _("Payment method")
+        verbose_name_plural = _("Payment methods")
+
+    journal = dd.ForeignKey('ledger.Journal')
+
+
 #
 class Account(StructuredReferrable, BabelNamed, Sequenced):
     ref_max_length = settings.SITE.plugins.ledger.ref_length
@@ -830,7 +841,6 @@ class RegistrableVoucher(Registrable, Voucher):
     toggle_state = ToggleState()
     hide_editable_number = True
 
-
     def __str__(self):
         # if not isinstance(dd.plugins.ledger.registered_states, tuple):
         #     raise Exception("registered_states is {}".format(dd.plugins.ledger.registered_states))
