@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2008-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.db import models
 from django.db.models import OuterRef, Subquery, Sum
@@ -204,6 +204,11 @@ class PaymentTerms(dd.Table):
     """
 
 
+class PaymentMethods(dd.Table):
+    required_roles = dd.login_required(LedgerStaff)
+    model = "ledger.PaymentMethod"
+
+
 class Vouchers(dd.Table):
     abstract = True
     required_roles = dd.login_required(LedgerUser)
@@ -800,21 +805,21 @@ class Creditors(DebtorsCreditors):
 ##
 
 
-class Situation(Report):
-    """
-    A report consisting of the following tables:
-
-   -  :class:`Debtors`
-   -  :class:`Creditors`
-
-    """
-    label = _("Situation")
-    help_text = _("Overview of the financial situation on a given date.")
-    required_roles = dd.login_required(AccountingReader)
-
-    parameters = mixins.Today()
-
-    report_items = (Debtors, Creditors)
+# class Situation(Report):
+#     """
+#     A report consisting of the following tables:
+#
+#    -  :class:`Debtors`
+#    -  :class:`Creditors`
+#
+#     """
+#     label = _("Situation")
+#     help_text = _("Overview of the financial situation on a given date.")
+#     required_roles = dd.login_required(AccountingReader)
+#
+#     parameters = mixins.Today()
+#
+#     report_items = (Debtors, Creditors)
 
 
 # class ActivityReport(Report):
