@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2009-2018 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from builtins import str
 
@@ -154,7 +154,7 @@ class Note(TypedPrintable,
 
     def get_change_owner(self):
         return self.project
-    
+
     # def get_change_observers(self, ar=None):
     #     # in lino_welfare the project is pcsw.Client
     #     prj = self.project
@@ -166,11 +166,11 @@ class Note(TypedPrintable,
         yield E.p(
             gettext("Subject"), ': ', self.subject,
             E.br(), gettext("Client"), ': ', ar.obj2memo(self.project))
-        
-    
+
+
 
 if dd.is_installed('contacts'):
-    
+
     dd.update_field(
         Note, 'company', verbose_name=_("Recipient (Organization)"))
     dd.update_field(
@@ -236,7 +236,7 @@ class NotesByX(Notes):
             s += [" ", obj.time.strftime(
                 settings.SITE.time_format_strftime)]
         s+= [" ", obj.obj2href(ar)]
-        if obj.user != ar.get_user():
+        if obj.user is not None and obj.user != ar.get_user():
             s += [' (', obj.user.initials or str(obj.user), ")"]
         if obj.subject:
             s += [' ', obj.subject]
@@ -272,5 +272,3 @@ dd.inject_field(
         help_text=_("""\
 Note Type used by system notes.
 If this is empty, then system notes won't create any entry to the Notes table.""")))
-
-
