@@ -1,5 +1,5 @@
 # Copyright 2008-2018 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
 Adds functionality for managing products.
@@ -33,7 +33,7 @@ class Plugin(ad.Plugin):
         for pt in site.models.products.ProductTypes.get_list_items():
             m.add_action(pt.table_name, label=pt.text)
         # m.add_action('products.Products')
-        m.add_action('products.ProductCats')
+        m.add_action('products.Categories')
 
         # mg = site.plugins.sales
         # m2 = m.add_menu(mg.app_label, mg.verbose_name)
@@ -43,3 +43,4 @@ class Plugin(ad.Plugin):
         mg = self.get_menu_group()
         m = m.add_menu(mg.app_label, mg.verbose_name)
         m.add_action('products.PriceFactors')
+        # m.add_action('products.ProductTypes')
