@@ -1,7 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2014 Rumma & Ko Ltd
-#
-# License: BSD (see file COPYING for details)
+# Copyright 2014-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """This is not yet used nor tested.  The idea is to collect some
 product repertoire using real products. To be complete this would
@@ -17,7 +16,7 @@ from lino.api import dd
 
 def objects():
 
-    productcat = Instantiator('products.ProductCat').build
+    productcat = Instantiator('products.Category').build
     product = Instantiator('products.Product', "cat name").build
 
     food = productcat(**dd.babel_values(
@@ -25,7 +24,7 @@ def objects():
         en="Food", et="Toit", de="Lebensmittel", fr="Alimentaire"))
     yield food
     yield product(food, "Le petit Fagnard", **dd.babel_values(
-        'description',
+        'body',
         en="Handmade cheese from Hautes Ardennes",
         et="Käsitsi valmistatud juust Ardenne'idest",
         de="Handgemachter Käse aus den Hohen Ardennen",
@@ -38,4 +37,3 @@ def objects():
             'contacts.Company',
             "name country:isocode city:zip_code").build
         yield company("Fromagerie du Troufleur", "BE", "4950 Waimes")
-
