@@ -1,28 +1,19 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2009-2021 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
-
-# Note that this module may not have a docstring because any
-# global variable defined here will override the global
-# namespace of lino/__init__.py who includes it with execfile.
-
-# This module is part of the Lino test suite.
-# To test only this module:
-#
-#   $ python setup.py test -s tests.PackagesTests
+# License: GNU Affero General Public License v3 (see file COPYING for details)
+# $ python setup.py test -s tests.PackagesTests
 
 
 SETUP_INFO = dict(
     name='lino-xl',
-    version='21.3.0',
+    version='21.4.0',
     install_requires=['lino'],  # odfpy dependency now in lino_xl.lib.appypod
     tests_require=[],
     description="Lino Extensions Library",
-    license='BSD-2-Clause',
+    license_files=['COPYING'],
     author='Rumma & Ko Ltd',
     author_email='info@saffre-rumma.net',
-    url="http://www.lino-framework.org",
-    # ~ test_suite = 'lino_xl.test_apps',
+    url="https://gitlab.com/lino-framework/xl",
     test_suite='tests')
 
 SETUP_INFO.update(long_description="""
@@ -32,13 +23,12 @@ applications.
 
 - This repository is considered an integral part of the Lino framework, which is
   documented as a whole in the `Lino Book
-  <http://www.lino-framework.org/about/overview.html>`__.
+  <https://www.lino-framework.org/about/overview.html>`__.
 
-- Your feedback is welcome.  Our `community page
-  <http://www.lino-framework.org/community>`__ explains how to contact us.
+- Your feedback is welcome.  See https://community.lino-framework.org
 
 - API changes to this repository are logged at
-  http://www.lino-framework.org/changes/
+  https://www.lino-framework.org/changes/
 
 
 """)
@@ -138,6 +128,8 @@ lino_xl.lib.statbel.countries.fixtures
 lino_xl.lib.thirds
 lino_xl.lib.topics
 lino_xl.lib.userstats
+lino_xl.lib.shopping
+lino_xl.lib.shopping.fixtures
 lino_xl.lib.xl
 
 lino_xl.lib.finan
@@ -188,7 +180,7 @@ Environment :: Web Environment
 Framework :: Django
 Intended Audience :: Developers
 Intended Audience :: System Administrators
-License :: OSI Approved :: BSD License
+License :: OSI Approved :: GNU Affero General Public License v3
 Natural Language :: English
 Natural Language :: French
 Natural Language :: German
